.. :changelog:

History
-------

0.6.0 (2018-11-15)
++++++++++++++++++

* New function: rest_api.delete_observation()

0.5.0 (2018-11-05)
++++++++++++++++++

* New function: node_api.get_observation()

0.4.0 (2018-11-05)
++++++++++++++++++

* create_observation() now raises exceptions in case of errors.

0.3.0 (2018-11-05)
++++++++++++++++++

* update_observation() now raises exceptions in case of errors.

0.2.0 (2018-10-31)
++++++++++++++++++

* Better infrastructure (type annotations, documentation, ...)
* Dropped support for Python 2.
* New function: update_observation()
* rest_api.AuthenticationError is now exceptions.AuthenticationError


0.1.0 (2018-10-10)
++++++++++++++++++

* First release on PyPI.
